@@ -1,4 +1,5 @@
-﻿define(['browser', 'datetime', 'libraryBrowser', 'listView', 'userdataButtons', 'cardStyle'], function (browser, datetime, libraryBrowser, listView, userdataButtons) {
+﻿define(['browser', 'datetime', 'libraryBrowser', 'listView', 'userdataButtons', 'imageLoader', 'cardStyle'], function (browser, datetime, libraryBrowser, listView, userdataButtons, imageLoader) {
+    'use strict';
 
     function showSlideshowMenu(context) {
         require(['scripts/slideshow'], function () {
@@ -220,7 +221,7 @@
         currentImgUrl = url;
 
         if (url) {
-            ImageLoader.lazyImage(context.querySelector('.nowPlayingPageImage'), url);
+            imageLoader.lazyImage(context.querySelector('.nowPlayingPageImage'), url);
         } else {
             context.querySelector('.nowPlayingPageImage').style.backgroundImage = '';
         }
@@ -447,7 +448,7 @@
                     }
                 }
 
-                ImageLoader.lazyChildren(itemsContainer);
+                imageLoader.lazyChildren(itemsContainer);
             });
         }
 
