@@ -1,4 +1,5 @@
-﻿define(['appStorage', 'events', 'browser'], function (appStorage, events, browser) {
+﻿define(['appSettings', 'events', 'browser'], function (appSettings, events, browser) {
+    'use strict';
 
     var currentDisplayInfo;
     var datetime;
@@ -99,17 +100,22 @@
 
                 Dashboard.hideLoadingMsg();
 
-                actionsheet.show({
+                var menuOptions = {
                     title: Globalize.translate('HeaderSelectPlayer'),
                     items: menuItems,
                     positionTo: button,
 
-                    // Unfortunately we can't allow the url to change or chromecast will throw a security error
-                    // Might be able to solve this in the future by moving the dialogs to hashbangs
-                    enableHistory: enableHistory !== false && !browser.chrome,
                     resolveOnClick: true
 
-                }).then(function (id) {
+                };
+
+                // Unfortunately we can't allow the url to change or chromecast will throw a security error
+                // Might be able to solve this in the future by moving the dialogs to hashbangs
+                if (!((enableHistory !== false && !browser.chrome) || AppInfo.isNativeApp)) {
+                    menuOptions.enableHistory = false;
+                }
+
+                actionsheet.show(menuOptions).then(function (id) {
 
                     var target = targets.filter(function (t) {
                         return t.id == id;
@@ -454,22 +460,24 @@
             });
         };
 
-        function doWithPlaybackValidation(player, fn) {
+        function validatePlayback(player) {
 
             if (!player.isLocalPlayer) {
-                fn();
-                return;
+                return Promise.resolve();
             }
 
-            requirejs(["registrationservices"], function (registrationServices) {
+            return new Promise(function (resolve, reject) {
 
-                self.playbackTimeLimitMs = null;
+                requirejs(["registrationServices"], function (registrationServices) {
 
-                registrationServices.validateFeature('playback').then(fn, function () {
+                    self.playbackTimeLimitMs = null;
 
-                    self.playbackTimeLimitMs = lockedTimeLimitMs;
-                    startAutoStopTimer();
-                    fn();
+                    registrationServices.validateFeature('playback').then(resolve, function () {
+
+                        self.playbackTimeLimitMs = lockedTimeLimitMs;
+                        startAutoStopTimer();
+                        resolve();
+                    });
                 });
             });
         }
@@ -504,7 +512,7 @@
             if (enabled != null) {
 
                 var val = enabled ? '1' : '0';
-                appStorage.setItem('displaymirror--' + Dashboard.getCurrentUserId(), val);
+                appSettings.set('displaymirror--' + Dashboard.getCurrentUserId(), val);
 
                 if (enabled) {
                     mirrorIfEnabled();
@@ -512,23 +520,23 @@
                 return;
             }
 
-            return (appStorage.getItem('displaymirror--' + Dashboard.getCurrentUserId()) || '') != '0';
+            return (appSettings.get('displaymirror--' + Dashboard.getCurrentUserId()) || '') != '0';
         };
 
         self.play = function (options) {
 
             if (options.enableRemotePlayers === false) {
                 if (!currentPlayer.isLocalPlayer) {
-                    return;
+                    return Promise.reject();
                 }
             }
 
-            doWithPlaybackValidation(currentPlayer, function () {
+            return validatePlayback(currentPlayer).then(function () {
                 if (typeof (options) === 'string') {
                     options = { ids: [options] };
                 }
 
-                currentPlayer.play(options);
+                return currentPlayer.play(options);
             });
         };
 
@@ -539,7 +547,7 @@
                 id = id.Id;
             }
 
-            doWithPlaybackValidation(currentPlayer, function () {
+            validatePlayback(currentPlayer).then(function () {
                 currentPlayer.shuffle(id);
             });
         };
@@ -551,7 +559,7 @@
                 id = id.Id;
             }
 
-            doWithPlaybackValidation(currentPlayer, function () {
+            validatePlayback(currentPlayer).then(function () {
                 currentPlayer.instantMix(id);
             });
         };
@@ -881,25 +889,26 @@
 
             return new Promise(function (resolve, reject) {
 
-                require(['localassetmanager'], function (LocalAssetManager) {
+                require([], function () {
+                    //require(['localassetmanager'], function (LocalAssetManager) {
 
                     var serverInfo = ApiClient.serverInfo();
 
-                    if (serverInfo.Id) {
-                        LocalAssetManager.getLocalMediaSource(serverInfo.Id, itemId).then(function (localMediaSource) {
-                            // Use the local media source if a specific one wasn't requested, or the smae one was requested
-                            if (localMediaSource && (!mediaSource || mediaSource.Id == localMediaSource.Id)) {
+                    //if (serverInfo.Id) {
+                    //    LocalAssetManager.getLocalMediaSource(serverInfo.Id, itemId).then(function (localMediaSource) {
+                    //        // Use the local media source if a specific one wasn't requested, or the smae one was requested
+                    //        if (localMediaSource && (!mediaSource || mediaSource.Id == localMediaSource.Id)) {
 
-                                var playbackInfo = getPlaybackInfoFromLocalMediaSource(itemId, deviceProfile, startPosition, localMediaSource);
+                    //            var playbackInfo = getPlaybackInfoFromLocalMediaSource(itemId, deviceProfile, startPosition, localMediaSource);
 
-                                resolve(playbackInfo);
-                                return;
-                            }
+                    //            resolve(playbackInfo);
+                    //            return;
+                    //        }
 
-                            getPlaybackInfoWithoutLocalMediaSource(itemId, deviceProfile, startPosition, mediaSource, audioStreamIndex, subtitleStreamIndex, liveStreamId, resolve, reject);
-                        });
-                        return;
-                    }
+                    //        getPlaybackInfoWithoutLocalMediaSource(itemId, deviceProfile, startPosition, mediaSource, audioStreamIndex, subtitleStreamIndex, liveStreamId, resolve, reject);
+                    //    });
+                    //    return;
+                    //}
 
                     getPlaybackInfoWithoutLocalMediaSource(itemId, deviceProfile, startPosition, mediaSource, audioStreamIndex, subtitleStreamIndex, liveStreamId, resolve, reject);
                 });
@@ -975,7 +984,7 @@
             });
         };
 
-        self.supportsDirectPlay = function (mediaSource) {
+        self.supportsDirectPlay = function (mediaSource, itemType) {
 
             return new Promise(function (resolve, reject) {
                 if (mediaSource.SupportsDirectPlay) {
@@ -988,17 +997,21 @@
                         }
                         else {
                             var val = mediaSource.Path.toLowerCase().replace('https:', 'http').indexOf(ApiClient.serverAddress().toLowerCase().replace('https:', 'http').substring(0, 14)) == 0;
+                            //resolve(val || itemType !== 'TvChannel');
                             resolve(val);
                         }
                     }
 
                     if (mediaSource.Protocol == 'File') {
 
-                        require(['localassetmanager'], function (LocalAssetManager) {
+                        require(['filesystem'], function (fileSystem) {
 
-                            LocalAssetManager.fileExists(mediaSource.Path).then(function (exists) {
-                                console.log('LocalAssetManager.fileExists: path: ' + mediaSource.Path + ' result: ' + exists);
-                                resolve(exists);
+                            fileSystem.fileExists(mediaSource.Path).then(function () {
+                                console.log('fileSystem.fileExists: path: ' + mediaSource.Path + ' result: ' + true);
+                                resolve(true);
+                            }, function () {
+                                console.log('fileSystem.fileExists: path: ' + mediaSource.Path + ' result: ' + false);
+                                resolve(false);
                             });
                         });
                     }
