@@ -21,38 +21,14 @@
          }];
     }
 
-    function initSupporterInfo(view, params) {
-
-        view.querySelector('.supporterPromotion .mainText').innerHTML = globalize.translate('HeaderSyncRequiresSupporterMembership');
-
-        var apiClient = ApiClient;
-        apiClient.getPluginSecurityInfo().then(function (regInfo) {
-
-            if (regInfo.IsMBSupporter) {
-                view.querySelector('.supporterPromotionContainer').classList.add('hide');
-            } else {
-                view.querySelector('.supporterPromotionContainer').classList.remove('hide');
-            }
-
-        }, function () {
-
-            view.querySelector('.supporterPromotionContainer').classList.remove('hide');
-        });
-    }
-
     return function (view, params) {
 
-        initSupporterInfo(view, params);
         var mySyncJobList = new syncJobList({
             isLocalSync: params.mode === 'offline',
             serverId: ApiClient.serverId(),
             userId: params.mode === 'offline' ? null : ApiClient.getCurrentUserId(),
-            element: view.querySelector('.syncActivity')
-        });
-
-        events.on(mySyncJobList, 'jobedit', function (e, jobId, serverId) {
-
-            Dashboard.navigate('syncjob.html?id=' + jobId);
+            element: view.querySelector('.syncActivity'),
+            mode: params.mode
         });
 
         view.addEventListener('viewshow', function () {
